# -*- coding: utf-8 -*-
"""
Created on Tue Aug 25 08:42:31 2019

@author: Riccardo Busti, Niccolò Tubini
@license: creative commons 4.0
"""

import os
import pandas as pd
import numpy as np
import matplotlib
import math

def sum(a,b):
    return a+b

def minus(a,b):
    return a-b

def pro(a,b):
    return a*b

def div(a,b):
    return a/b

# versione 0.0.3
def sumabc(a,b,c):
    return a+b+c
